* KinJector version: (Use `kinjector -V` to get this.)
* KiCad version: (Use `Help => About KiCad => Copy Version Info` to get this.)
* Python version: (Use `python -V` to get this.)
* Operating System:

### Description

Describe what you were trying to get done.
Tell us what happened, what went wrong, and what you expected to happen.

### What I Did

```
Paste the command(s) you ran and the output.
```
